//#define XERR
#include "round.ih"

std::istream &Round::extract(istream &in)
{
    string modality;
    
    if (in >> d_age >> modality)      // at least one modality must be
    {                                 // specified
        do
        {
            d_idx = d_modalities.size();
            d_modalities.push_back(move(modality)); // 'modality' must be
                                                    // configured
        }
        while (in >> modality);

        in.clear();
    }

    return in;
}
